@@ -6,6 +6,10 @@ https://github.com/davidhalter/jedi
 
 """
 
+import os
+import sys
+
+
 from elpy.backends.nativebackend import NativeBackend
 
 
@@ -32,21 +36,38 @@ class JediBackend(NativeBackend):
 
     def rpc_get_completions(self, project_root, filename, source, offset):
         line, column = pos_to_linecol(source, offset)
-        script = self.jedi.Script(source, line, column, filename,
-                                  source_encoding='utf-8')
-        proposals = script.complete()
+        sys.path.append(project_root)
+        try:
+            script = self.jedi.Script(source, line, column, filename,
+                                      source_encoding='utf-8')
+            proposals = script.complete()
+        finally:
+            sys.path.pop()
         return [[proposal.complete, proposal.doc]
                 for proposal in proposals]
 
     def rpc_get_definition(self, project_root, filename, source, offset):
         line, column = pos_to_linecol(source, offset)
-        script = self.jedi.Script(source, line, column, filename,
-                                  source_encoding='utf-8')
-        locations = script.get_definition()
+        sys.path.append(project_root)
+        try:
+            script = self.jedi.Script(source, line, column, filename,
+                                      source_encoding='utf-8')
+            locations = script.get_definition()
+            # get_definition() can return silly stuff like __builtin__
+            # for int variables, so we fall back on goto() in those
+            # cases. See issue #76.
+            if (
+                    locations and
+                    locations[0].module_path and
+                    not os.path.exists(locations[0].module_path)
+            ):
+                locations = script.goto()
+        finally:
+            sys.path.pop()
         if not locations:
             return None
         else:
-            loc = locations[0]
+            loc = locations[-1]
             try:
                 with open(loc.module_path) as f:
                     offset = linecol_to_pos(f.read(),
@@ -57,13 +78,17 @@ class JediBackend(NativeBackend):
 
     def rpc_get_calltip(self, project_root, filename, source, offset):
         line, column = pos_to_linecol(source, offset)
-        script = self.jedi.Script(source, line, column, filename,
-                                  source_encoding='utf-8')
-        call = script.get_in_function_call()
+        sys.path.append(project_root)
+        try:
+            script = self.jedi.Script(source, line, column, filename,
+                                      source_encoding='utf-8')
+            call = script.get_in_function_call()
+        finally:
+            sys.path.pop()
         if call is None:
             return None
         return "{0}({1})".format(call.call_name,
-                                 ", ".join(param.code
+                                 ", ".join(param.get_code().strip()
                                            for param in call.params))
 
     def rpc_get_docstring(self, project_root, filename, source, offset):
