@@ -14,15 +14,6 @@ class RopeBackendTestCase(BackendTestCase):
         super(RopeBackendTestCase, self).setUp()
         self.backend = ropebackend.RopeBackend()
 
-    def project_file(self, relname, contents):
-        filename = super(RopeBackendTestCase, self).project_file(relname,
-                                                                 "")
-        self.backend.rpc_before_save(self.project_root, filename)
-        filename = super(RopeBackendTestCase, self).project_file(relname,
-                                                                 contents)
-        self.backend.rpc_after_save(self.project_root, filename)
-        return filename
-
 
 class TestInit(RopeBackendTestCase):
     def test_should_have_rope_as_name(self):
@@ -47,17 +38,6 @@ class TestGetProject(RopeBackendTestCase):
                                                    "/doesnotexist/"))
 
 
-class TestBeforeAfterSave(RopeBackendTestCase):
-    def test_should_not_fail_on_inexisting_file(self):
-        filename = self.project_root + "/doesnotexist"
-        self.backend.rpc_before_save(self.project_root, filename)
-        self.backend.rpc_after_save(self.project_root, filename)
-
-    def test_should_not_fail_if_file_is_none(self):
-        self.backend.rpc_before_save(self.project_root, None)
-        self.backend.rpc_after_save(self.project_root, None)
-
-
 class TestGetCompletions(RopeBackendTestCase):
     def test_should_return_completions(self):
         source, offset = source_and_offset("import multiprocessing\n"
@@ -165,6 +145,18 @@ class TestGetCompletions(RopeBackendTestCase):
         self.assertNotEqual(sorted(name for (name, doc) in completions),
                             sorted(["igParser"]))
 
+    def test_should_not_fail_for_short_module(self):
+        # This throws an error in Rope which elpy hopefully catches.
+        # See #186
+        source, offset = source_and_offset("from .. import foo_|_")
+        filename = self.project_file("test.py", source)
+        completions = self.backend.rpc_get_completions(self.project_root,
+                                                       filename,
+                                                       source,
+                                                       offset)
+        # This is strictly speaking superfluous. Just avoid an error.
+        self.assertIsNotNone(completions)
+
 
 class TestGetDefinition(RopeBackendTestCase):
     def test_should_return_location_in_same_file(self):
